pygeodesy.deprecated.datum

Package pygeodesy :: Package deprecated :: Module datum |
[frames] | no frames]

# Module datum

DEPRECATED on 2022.09.12, use module pygeodesy.datums or pygeodesy.ellipsoids instead.

Version: 24.12.31

Classes
| Datum Ellipsoid and transform parameters for an earth model.
| Transform Helmert datum transformation.
| Ellipsoid Ellipsoid with equatorial and polar radii, flattening, inverse flattening and other, often used, cached attributes, supporting oblate and prolate ellipsoidal and spherical earth models.
| Curvature2Tuple 2-Tuple `(meridional, prime_vertical)` of radii of curvature, both in `meter`, conventionally.

Variables
| R_FM = `6371000.0`
| R_KM = `6371.0087714149995`
| R_M = `6371008.771415`
| R_MA = `6378137.0`
| R_MB = `6356752.3`
| R_NM = `3440.06953100162`
| R_SM = `3958.7613160486508`
| R_VM = `6366707.0194937`
| Datums = `Datums.Sphere: Datum(name='Sphere', ellipsoid=Ellipso`...``
| Transforms = `Transforms.OSGB36: Transform(name='OSGB36', tx=-4`...``
| Ellipsoids = `Ellipsoids.Sphere: Ellipsoid(name='Sphere', a=637`...``
| __all__ = `_ALL_DEPRECATED.deprecated_datum`

Variables Details

  ### Datums Value:
      Datums.Sphere: Datum(name='Sphere', ellipsoid=Ellipsoids.Sphere, trans
      form=Transforms.WGS84),
      Datums.NAD83: Datum(name='NAD83', ellipsoid=Ellipsoids.GRS80, transfor
      m=Transforms.NAD83),
      Datums.OSGB36: Datum(name='OSGB36', ellipsoid=Ellipsoids.Airy1830, tra
      nsform=Transforms.OSGB36),
      Datums.WGS84: Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transfor
      m=Transforms.WGS84),
      ...

  ### Transforms Value:
      Transforms.OSGB36: Transform(name='OSGB36', tx=-446.45, ty=125.16, tz=
      -542.06, s1=1.0, rx=-7.2819e-07, ry=-1.1975e-06, rz=-4.0826e-06, s=20.
      489, sx=-0.1502, sy=-0.247, sz=-0.8421),
      Transforms.NAD83: Transform(name='NAD83', tx=1.004, ty=-1.91, tz=-0.51
      5, s1=1.0, rx=1.2945e-07, ry=1.6484e-09, rz=5.333e-08, s=-0.0015, sx=0
      .0267, sy=0.00034, sz=0.011),
      Transforms.WGS84: Transform(name='WGS84', tx=0.0, ty=0.0, tz=0.0, s1=1
      .0, rx=0.0, ry=0.0, rz=0.0, s=0.0, sx=0.0, sy=0.0, sz=0.0),
      ...

  ### Ellipsoids Value:
      Ellipsoids.Sphere: Ellipsoid(name='Sphere', a=6371008.771415, f=0, f_=
      0, b=6371008.771415),
      Ellipsoids.GRS80: Ellipsoid(name='GRS80', a=6378137, f=0.00335281, f_=
      298.2572221, b=6356752.31414035),
      Ellipsoids.WGS84: Ellipsoid(name='WGS84', a=6378137, f=0.00335281, f_=
      298.25722356, b=6356752.31424518),
      Ellipsoids.Airy1830: Ellipsoid(name='Airy1830', a=6377563.396, f=0.003
      34085, f_=299.3249646, b=6356256.90923729)